@@ -19,6 +19,7 @@
 
 import logging
 import time
+import os
 from base64 import b64encode
 
 from axolotl.ecc.djbec import DjbECPublicKey
@@ -51,18 +52,18 @@ UNDECIDED = 2
 
 
 class OmemoState:
-    def __init__(self, own_jid, connection, account, plugin):
+    def __init__(self, own_jid, db_con, account, xmpp_con):
         """ Instantiates an OmemoState object.
 
             :param connection: an :py:class:`sqlite3.Connection`
         """
         self.account = account
-        self.plugin = plugin
+        self.xmpp_con = xmpp_con
         self.session_ciphers = {}
         self.own_jid = own_jid
         self.device_ids = {}
         self.own_devices = []
-        self.store = LiteAxolotlStore(connection)
+        self.store = LiteAxolotlStore(db_con)
         self.encryption = self.store.encryptionStore
         for jid, device_id in self.store.getActiveDeviceTuples():
             if jid != own_jid:
@@ -199,7 +200,7 @@ class OmemoState:
             try:
                 key = self.handleWhisperMessage(sender_jid, sid, encrypted_key)
             except (NoSessionException, InvalidMessageException) as e:
-                log.warning('No Session found ' + e.message)
+                log.warning(e)
                 log.warning('sender_jid =>  ' + str(sender_jid) + ' sid =>' +
                             str(sid))
                 return
@@ -211,7 +212,7 @@ class OmemoState:
             log.warning('Duplicate message found ' + str(e.args))
             return
 
-        result = unicode(decrypt(key, iv, payload))
+        result = decrypt(key, iv, payload)
 
         log.debug("Decrypted Message => " + result)
         return result
@@ -293,12 +294,14 @@ class OmemoState:
             self.get_session_cipher(tup[0], tup[1])
 
         # Encrypt the message key with for each of receivers devices
-        for nick in self.plugin.groupchat[room]:
-            jid_to = self.plugin.groupchat[room][nick]
+        for nick in self.xmpp_con.groupchat[room]:
+            jid_to = self.xmpp_con.groupchat[room][nick]
             if jid_to == self.own_jid:
                 continue
             if jid_to in encrypted_jids:  # We already encrypted to this JID
                 continue
+            if jid_to not in self.session_ciphers:
+                continue
             for rid, cipher in self.session_ciphers[jid_to].items():
                 try:
                     if self.isTrusted(jid_to, rid) == TRUSTED:
@@ -355,12 +358,16 @@ class OmemoState:
         if gc:
             room = jid
             devicelist = []
-            for nick in self.plugin.groupchat[room]:
-                jid_to = self.plugin.groupchat[room][nick]
+            for nick in self.xmpp_con.groupchat[room]:
+                jid_to = self.xmpp_con.groupchat[room][nick]
                 if jid_to == self.own_jid:
                     continue
-                for device in self.device_ids[jid_to]:
-                    devicelist.append((jid_to, device))
+                try:
+                    for device in self.device_ids[jid_to]:
+                        devicelist.append((jid_to, device))
+                except KeyError:
+                    log.warning('no device ids found for %s', jid_to)
+                    continue
             return devicelist
 
         if jid == self.own_jid:
@@ -434,7 +441,7 @@ class OmemoState:
             key = sessionCipher.decryptPkmsg(preKeyWhisperMessage)
             # Publish new bundle after PreKey has been used
             # for building a new Session
-            self.plugin.publish_bundle(self.account)
+            self.xmpp_con.publish_bundle()
             self.add_device(recipient_id, device_id)
             return key
         except UntrustedIdentityException as e:
@@ -447,7 +454,7 @@ class OmemoState:
                   recipient_id)
         if self.isTrusted(recipient_id, device_id):
             sessionCipher = self.get_session_cipher(recipient_id, device_id)
-            key = sessionCipher.decryptMsg(whisperMessage)
+            key = sessionCipher.decryptMsg(whisperMessage, textMsg=False)
             self.add_device(recipient_id, device_id)
             return key
         else:
