@@ -105,8 +105,11 @@ class OMEMOConfigDialog(GajimPluginConfigDialog):
 
     def update_account_store(self):
         for account in sorted(app.contacts.get_accounts()):
-            if account not in self.disabled_accounts and \
-                    not self.is_in_accountstore(account):
+            if account in self.disabled_accounts:
+                continue
+            if account == 'Local':
+                continue
+            if not self.is_in_accountstore(account):
                 self.account_store.append(row=(account,))
 
     def update_account_combobox(self):
@@ -347,10 +350,13 @@ class OMEMOConfigDialog(GajimPluginConfigDialog):
         if PILLOW:
             path = self.get_qrcode(
                 app.get_jid_from_account(account), deviceid, ownfpr[2:])
-            self.qrcode.set_from_pixbuf(GdkPixbuf.Pixbuf.new_from_file(path))
+            pixbuf = GdkPixbuf.Pixbuf.new_from_file(path)
+            self.qrcode.set_from_pixbuf(pixbuf)
+            self.qrcode.show()
             self.qrinfo.hide()
         else:
             self.qrinfo.show()
+            self.qrcode.hide()
 
 
 class FingerprintWindow(Gtk.Dialog):
